==> jc-1.4.0.tar.gz: gnu/javax/rmi/CORBA/PortableRemoteObjectDelegateImpl.h <==
// public class gnu.javax.rmi.CORBA.PortableRemoteObjectDelegateImpl

// class file dependencies
// @dep_class 2fc0b42aaa33f156 gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl_H_
#define _JC_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_rmi_Remote$object;

// Typedefs
typedef struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_refs	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_refs;
typedef struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_nonrefs	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_nonrefs;
typedef struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$refs	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$refs;
typedef struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$nonrefs	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$nonrefs;
typedef struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object;

typedef const struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vmethods	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vmethods;
typedef const struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtable	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtable;
typedef const struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtype	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtype;

// Constructors
extern void _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *);

// Virtual methods
extern void _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method$connect$64cce43a3a8f81df(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method$exportObject$f24f2fffff6dde7d(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method$narrow$3c78d1e45f465b3b(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *);
extern struct _jc_object *_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method$toStub$eb510defe3584b97(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *);
extern void _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method$unexportObject$be7fa0efab735c7e(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method_info$connect$64cce43a3a8f81df;
extern _jc_method _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method_info$exportObject$f24f2fffff6dde7d;
extern _jc_method _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method_info$narrow$3c78d1e45f465b3b;
extern _jc_method _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method_info$toStub$eb510defe3584b97;
extern _jc_method _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method_info$unexportObject$be7fa0efab735c7e;

// Virtual methods structure
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vmethods {
	void	(*connect$64cce43a3a8f81df)(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *, struct _jc_object *);
	void	(*exportObject$f24f2fffff6dde7d)(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*narrow$3c78d1e45f465b3b)(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *);
	struct _jc_object	*(*toStub$eb510defe3584b97)(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *);
	void	(*unexportObject$be7fa0efab735c7e)(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vmethods	gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl;
};

// Vtype
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtype {
	_jc_type			type;
	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$refs {
    _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_refs	gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_nonrefs	gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl;
};

// Object instance structure
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object {
	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtype	*vtype;
	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtype _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$class_object;

#endif	/* _JC_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl_H_ */

==> jc-1.4.6.tar.gz: gnu/javax/rmi/CORBA/PortableRemoteObjectDelegateImpl.h <==
// public class gnu.javax.rmi.CORBA.PortableRemoteObjectDelegateImpl

// class file dependencies
// @dep_class 2fc0b42aaa33f156 gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl_H_
#define _JC_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_rmi_Remote$object;

// Typedefs
typedef struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_refs	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_refs;
typedef struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_nonrefs	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_nonrefs;
typedef struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$refs	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$refs;
typedef struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$nonrefs	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$nonrefs;
typedef struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object;

typedef const struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vmethods	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vmethods;
typedef const struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtable	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtable;
typedef const struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtype	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtype;

// Constructors
extern void _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method$connect$64cce43a3a8f81df(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method$exportObject$f24f2fffff6dde7d(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method$narrow$3c78d1e45f465b3b(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method$toStub$eb510defe3584b97(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method$unexportObject$be7fa0efab735c7e(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method_info$connect$64cce43a3a8f81df;
extern _jc_method _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method_info$exportObject$f24f2fffff6dde7d;
extern _jc_method _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method_info$narrow$3c78d1e45f465b3b;
extern _jc_method _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method_info$toStub$eb510defe3584b97;
extern _jc_method _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$method_info$unexportObject$be7fa0efab735c7e;

// Virtual methods structure
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vmethods {
	void	(*connect$64cce43a3a8f81df)(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*exportObject$f24f2fffff6dde7d)(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*narrow$3c78d1e45f465b3b)(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*toStub$eb510defe3584b97)(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*unexportObject$be7fa0efab735c7e)(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vmethods	gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl;
};

// Vtype
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtype {
	_jc_type			type;
	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$refs {
    _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_refs	gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$sub_nonrefs	gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl;
};

// Object instance structure
struct _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$object {
	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtype	*vtype;
	_jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$vtype _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl$class_object;

#endif	/* _JC_gnu_javax_rmi_CORBA_PortableRemoteObjectDelegateImpl_H_ */
